@@ -59,83 +59,55 @@ sub BUILDARGS {
     return @_;
 }
 
-sub method {
-    my ( $self, $value ) = @_;
+sub set_or_get_from_env {
+    my ( $self, $var, $value ) = @_;
     if ($value) {
-        $self->set_to_env( 'REQUEST_METHOD', $value );
+        $self->set_to_env( $var, $value );
+        return;
     }
     else {
-        return $self->get_from_env('REQUEST_METHOD');
+        return $self->get_from_env($var);
     }
 }
 
+sub method {
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'REQUEST_METHOD', $value );
+}
+
 sub host {
-    my ($self, $value) = @_;
-    if ($value) {
-        $self->set_to_env('SERVER_NAME', $value);
-    }else{
-        return $self->get_from_env('SERVER_NAME');
-    }
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'SERVER_NAME', $value );
 }
 
 sub port {
     my ( $self, $value ) = @_;
-    if ($value) {
-        $self->set_to_env( 'SERVER_PORT', $value );
-    }
-    else {
-        return $self->get_from_env('SERVER_PORT');
-    }
+    return $self->set_or_get_from_env( 'SERVER_PORT', $value );
 }
 
 sub script_name {
     my ( $self, $value ) = @_;
-    if ($value) {
-        $self->set_to_env( 'SCRIPT_NAME', $value );
-    }
-    else {
-        return $self->get_from_env('SCRIPT_NAME');
-    }
+    return $self->set_or_get_from_env( 'SCRIPT_NAME', $value );
 }
 
 sub request_uri {
-    my ($self, $value) = @_;
-    if ($value) {
-        $self->set_to_env( 'REQUEST_URI', $value );
-    }
-    else {
-        return $self->get_from_env('REQUEST_URI');
-    }
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'REQUEST_URI', $value );
 }
 
 sub scheme {
-    my ($self, $value) = @_;
-    if ($value) {
-        $self->set_to_env( 'spore.url_scheme', $value );
-    }
-    else {
-        return $self->get_from_env('spore.url_scheme');
-    }
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'spore.url_scheme', $value );
 }
 
 sub logger {
-    my ($self, $value) = @_;
-    if ($value) {
-        $self->set_to_env( 'sporex.logger', $value );
-    }
-    else {
-        return $self->get_from_env('sporex.logger');
-    }
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'sporex.logger', $value );
 }
 
 sub body {
-    my ($self, $value) = @_;
-    if ($value) {
-        $self->set_to_env( 'spore.payload', $value );
-    }
-    else {
-        return $self->get_from_env('spore.payload');
-    }
+    my ( $self, $value ) = @_;
+    return $self->set_or_get_from_env( 'spore.payload', $value );
 }
 
 sub base {
@@ -153,16 +125,14 @@ sub uri {
     my ($self, $path_info, $query_string) = @_;
 
     if ( !defined $path_info || !defined $query_string ) {
-        my @path_info = $self->_path;
-        $path_info    = $path_info[0] if !$path_info;
-        $query_string = $path_info[1] if !$query_string;
+        ($path_info,$query_string) = $self->_path;
     }
 
     my $base = $self->_uri_base;
 
     my $path_escape_class = '^A-Za-z0-9\-\._~/';
 
-    my $path = URI::Escape::uri_escape($path_info || '', $path_escape_class);
+    my $path = URI::Escape::uri_escape($path_info // '', $path_escape_class);
 
     if (defined $query_string && length($query_string) > 0) {
         $path .= '?' . $query_string;
@@ -355,7 +325,7 @@ Net::HTTP::Knork::Request - HTTP request object from SPORE env hash
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 SYNOPSIS
 
